@@ -36,7 +36,7 @@ LDAPObject_whoami(LDAPObject *self, PyObject *args)
 	rc = ldap_whoami(self->ldap, sctrls, cctrls, &msgid);
 	LDAP_END_ALLOW_THREADS
 	if (rc != LDAP_SUCCESS) {
-		PyErr_SetString(LDAPError, ldap_err2string(rc));
+		PyErr_Format(LDAPError, "%s (%d)", ldap_err2string(rc), rc);
 		return NULL;
 	}
 
